@@ -3,8 +3,8 @@
 != Error handling
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_error.f90,v 1.16 2007/06/16 06:20:25 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070629 $
+! Version::   $Id: dc_error.f90,v 1.17 2007/07/10 17:18:58 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070711 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -342,7 +342,25 @@ module dc_error
   ! -404    :: [ <b>DC_EBADTIMEZONE</b> ]
   !            <b></b> :: time zone (<i>cause_c</i>) is invalid
   !
-  ! -405-499  :: <b>                     </b>
+  ! -405    :: [ <b>DC_EFILENAMEEMPTY</b> ]
+  !            <b></b> :: filename is empty
+  !
+  ! -406    :: [ <b>DC_EBADFILEOPMODE</b> ]
+  !            <b></b> :: file open mode (<i>cause_c</i>) is invalid
+  !
+  ! -407    :: [ <b>DC_ENOUNITNUM</b> ]
+  !            <b></b> :: available unit number is not found within (<i>cause_c</i>)
+  !
+  ! -408    :: [ <b>DC_ENOFILEEXIST</b> ]
+  !            <b></b> :: file (<i>cause_c</i>) is not found
+  !
+  ! -409    :: [ <b>DC_ENOFILEREAD</b> ]
+  !            <b></b> :: file (<i>cause_c</i>) is not readable
+  !
+  ! -410    :: [ <b>DC_ENOFILEWRITE</b> ]
+  !            <b></b> :: file (<i>cause_c</i>) is not writable
+  !
+  ! -411-499  :: <b>                     </b>
   !                <b></b> :: ( DC 桼ƥƥγĥΤͽ.
   !                           Reserved area for future extensions of DC utilities)
   !
@@ -427,11 +445,17 @@ module dc_error
   !
   ! -400 ʲ: dc 桼ƥƥΥ顼
   !
-  integer, parameter, public:: DC_ENOTINIT     = -400
-  integer, parameter, public:: DC_EALREADYINIT = -401
-  integer, parameter, public:: DC_EBADUNIT     = -402
-  integer, parameter, public:: DC_EBADCALTYPE  = -403
-  integer, parameter, public:: DC_EBADTIMEZONE = -404
+  integer, parameter, public:: DC_ENOTINIT       = -400
+  integer, parameter, public:: DC_EALREADYINIT   = -401
+  integer, parameter, public:: DC_EBADUNIT       = -402
+  integer, parameter, public:: DC_EBADCALTYPE    = -403
+  integer, parameter, public:: DC_EBADTIMEZONE   = -404
+  integer, parameter, public:: DC_EFILENAMEEMPTY = -405
+  integer, parameter, public:: DC_EBADFILEOPMODE = -406
+  integer, parameter, public:: DC_ENOUNITNUM     = -407
+  integer, parameter, public:: DC_ENOFILEEXIST   = -408
+  integer, parameter, public:: DC_ENOFILEREAD    = -409
+  integer, parameter, public:: DC_ENOFILEWRITE   = -410
 
   !
   ! -1000 ʲ: 桼
@@ -525,16 +549,28 @@ contains
       ! -400 or less: Error of DC utilities
       !
     case(DC_ENOTINIT)
-      msg = " object (" // trim(cause_string) //") is not initialized"
+      msg = " object (" // trim(cause_string) // ") is not initialized"
     case(DC_EALREADYINIT)
       msg = ' object (' // trim(cause_string) // ') is already initialized'
     case(DC_EBADUNIT)
-      msg = " unit (" // trim(cause_string) //") is invalid"
+      msg = " unit (" // trim(cause_string) // ") is invalid"
     case(DC_EBADCALTYPE)
       write(message, "(' calendar type (', i4, ') is invalid')") cause_int
       msg = trim(message)
     case(DC_EBADTIMEZONE)
-      msg = " time zone (" // trim(cause_string) //") is invalid"
+      msg = " time zone (" // trim(cause_string) // ") is invalid"
+    case(DC_EFILENAMEEMPTY)
+      msg = " filename is empty"
+    case(DC_EBADFILEOPMODE)
+      msg = " file open mode (" // trim(cause_string) // ") is invalid"
+    case(DC_ENOUNITNUM)
+      msg = " available unit number is not found within (" // trim(cause_string) // ")"
+    case(DC_ENOFILEEXIST)
+      msg = " file (" // trim(cause_string) // ") is not found"
+    case(DC_ENOFILEREAD)
+      msg = " file (" // trim(cause_string) // ") is not readable"
+    case(DC_ENOFILEWRITE)
+      msg = " file (" // trim(cause_string) // ") is not writable"
       !
       ! -1000 ʲ: 桼
       ! -1000 or less: User-defined error
