@@ -2,8 +2,8 @@ program dc_args_test
   use dc_types
   use dc_string, only: StoA, JoinChar
   use dc_args, only: ARGS, Open, Close, &
-    & Option, Put_Line, Debug, Help, Strict, Get, HelpMsg, Number
-  use dc_test, only: Compare
+    & Option, PutLine, Debug, Help, Strict, Get, HelpMsg, Number
+  use dc_test, only: AssertEqual
   implicit none
   type(ARGS) :: arg
   logical :: OPT_size
@@ -13,7 +13,7 @@ program dc_args_test
 continue
 
   call Open(arg)
-  call HelpMsg(arg, 'Title', 'dcargs $Revision: 1.5 $ :: Test program of dc_args')
+  call HelpMsg(arg, 'Title', 'dcargs $Revision: 1.7 $ :: Test program of dc_args')
   call HelpMsg(arg, 'Usage', 'dcargs [Options] arg1, arg2, ...')
   call Option(arg, StoA('-s', 'size'), &
     & OPT_size, help="Return number of arguments")
@@ -34,16 +34,16 @@ continue
   call Strict(arg)
   call Get(arg, argv)
 
-  call Compare('Number of arguments test', 3, number(arg))
+  call AssertEqual('Number of arguments test', 3, number(arg))
 
-  call Compare('Short option test 1', .true., OPT_size)
+  call AssertEqual('Short option test 1', .true., OPT_size)
 
-  call Compare('Long option test 1', .true., OPT_namelist)
-  call Compare('Long option test 2', 'test.nml', VAL_namelist)
+  call AssertEqual('Long option test 1', .true., OPT_namelist)
+  call AssertEqual('Long option test 2', 'test.nml', VAL_namelist)
 
   char = trim(JoinChar(argv))
 
-  call Compare('Strings of arguments test', 'arg1, arg2, arg3', char)
+  call AssertEqual('Strings of arguments test', 'arg1, arg2, arg3', char)
 
   deallocate(argv)
   call Close(arg)
